@@ -18,12 +18,10 @@
 
 #include <stdio.h>
 #include <unistd.h>
-#include <termios.h>
 #include <fcntl.h>
 #include <string.h>
 #include <sys/time.h>
 #include <errno.h>
-#include <sys/ioctl.h>
 #include <stdlib.h>
 #include <ctype.h>
 
