@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 #include "config.h"
 #include "casio-qv-commands.h"
@@ -374,10 +374,11 @@ int
 QVcapture (Camera *camera)
 {
 	unsigned char cmd[2];
+	unsigned char b;
 
 	cmd[0] = 'D';
 	cmd[1] = 'R';
-	CR (QVsend (camera, cmd, 2, NULL, 0));
+	CR (QVsend (camera, cmd, 2, &b, 1));
 
 	return (GP_OK);
 }
@@ -429,5 +430,7 @@ QVsetspeed (Camera *camera, int speed)
         settings.serial.speed = speed;
         CR (gp_port_set_settings (camera->port, settings));
 
+	CR (QVping (camera));
+
 	return (GP_OK);
 }
