@@ -773,7 +773,7 @@ ptp_unpack_DPV (
 static inline int
 ptp_unpack_DPD (PTPParams *params, unsigned char* data, PTPDevicePropDesc *dpd, unsigned int dpdlen)
 {
-	unsigned int offset=0, ret;
+	unsigned int offset = 0, ret;
 
 	memset (dpd, 0, sizeof(*dpd));
 	dpd->DevicePropertyCode=dtoh16a(&data[PTP_dpd_DevicePropertyCode]);
@@ -843,13 +843,106 @@ outofmemory:
 	return 0;
 }
 
+/* Device Property pack/unpack */
+#define PTP_dpd_Sony_DevicePropertyCode	0
+#define PTP_dpd_Sony_DataType		2
+#define PTP_dpd_Sony_GetSet		4
+#define PTP_dpd_Sony_Unknown		5
+#define PTP_dpd_Sony_FactoryDefaultValue	6
+
+static inline int
+ptp_unpack_Sony_DPD (PTPParams *params, unsigned char* data, PTPDevicePropDesc *dpd, unsigned int dpdlen, unsigned int *poffset)
+{
+	unsigned int ret;
+
+	memset (dpd, 0, sizeof(*dpd));
+	dpd->DevicePropertyCode=dtoh16a(&data[PTP_dpd_Sony_DevicePropertyCode]);
+	dpd->DataType=dtoh16a(&data[PTP_dpd_Sony_DataType]);
+
+#if 0
+	dpd->GetSet=dtoh8a(&data[PTP_dpd_Sony_GetSet]);
+#endif
+	dpd->GetSet=1;
+
+	dpd->FormFlag=PTP_DPFF_None;
+
+	*poffset = PTP_dpd_Sony_FactoryDefaultValue;
+	ret = ptp_unpack_DPV (params, data, poffset, dpdlen, &dpd->FactoryDefaultValue, dpd->DataType);
+	if (!ret) goto outofmemory;
+	if ((dpd->DataType == PTP_DTC_STR) && (*poffset == dpdlen))
+		return 1;
+	ret = ptp_unpack_DPV (params, data, poffset, dpdlen, &dpd->CurrentValue, dpd->DataType);
+	if (!ret) goto outofmemory;
+
+	/* if offset==0 then Data Type format is not supported by this
+	   code or the Data Type is a string (with two empty strings as
+	   values). In both cases Form Flag should be set to 0x00 and FORM is
+	   not present. */
+
+	if (*poffset==PTP_dpd_Sony_FactoryDefaultValue)
+		return 1;
+
+	dpd->FormFlag=dtoh8a(&data[*poffset]);
+	*poffset+=sizeof(uint8_t);
+
+	switch (dpd->FormFlag) {
+	case PTP_DPFF_Range:
+		ret = ptp_unpack_DPV (params, data, poffset, dpdlen, &dpd->FORM.Range.MinimumValue, dpd->DataType);
+		if (!ret) goto outofmemory;
+		ret = ptp_unpack_DPV (params, data, poffset, dpdlen, &dpd->FORM.Range.MaximumValue, dpd->DataType);
+		if (!ret) goto outofmemory;
+		ret = ptp_unpack_DPV (params, data, poffset, dpdlen, &dpd->FORM.Range.StepSize, dpd->DataType);
+		if (!ret) goto outofmemory;
+		break;
+	case PTP_DPFF_Enumeration: {
+		int i;
+#define N	dpd->FORM.Enum.NumberOfValues
+		N = dtoh16a(&data[*poffset]);
+		*poffset+=sizeof(uint16_t);
+		dpd->FORM.Enum.SupportedValue = malloc(N*sizeof(dpd->FORM.Enum.SupportedValue[0]));
+		if (!dpd->FORM.Enum.SupportedValue)
+			goto outofmemory;
+
+		memset (dpd->FORM.Enum.SupportedValue,0 , N*sizeof(dpd->FORM.Enum.SupportedValue[0]));
+		for (i=0;i<N;i++) {
+			ret = ptp_unpack_DPV (params, data, poffset, dpdlen, &dpd->FORM.Enum.SupportedValue[i], dpd->DataType);
+
+			/* Slightly different handling here. The HP PhotoSmart 120
+			 * specifies an enumeration with N in wrong endian
+			 * 00 01 instead of 01 00, so we count the enum just until the
+			 * the end of the packet.
+			 */
+			if (!ret) {
+				if (!i)
+					goto outofmemory;
+				dpd->FORM.Enum.NumberOfValues = i;
+				break;
+			}
+		}
+		}
+	}
+#undef N
+	return 1;
+outofmemory:
+	ptp_free_devicepropdesc(dpd);
+	return 0;
+}
+
 static inline void
 duplicate_PropertyValue (const PTPPropertyValue *src, PTPPropertyValue *dst, uint16_t type) {
+	if (type == PTP_DTC_STR) {
+		if (src->str)
+			dst->str = strdup(src->str);
+		else
+			dst->str = NULL;
+		return;
+	}
+
 	if (type & PTP_DTC_ARRAY_MASK) {
 		unsigned int i;
 
 		dst->a.count = src->a.count;
-		dst->a.v = malloc (sizeof(src->a.v)*src->a.count);
+		dst->a.v = malloc (sizeof(src->a.v[0])*src->a.count);
 		for (i=0;i<src->a.count;i++)
 			duplicate_PropertyValue (&src->a.v[i], &dst->a.v[i], type & ~PTP_DTC_ARRAY_MASK);
 		return;
@@ -867,7 +960,6 @@ duplicate_PropertyValue (const PTPPropertyValue *src, PTPPropertyValue *dst, uin
 	case PTP_DTC_INT128:	dst->i128 = src->i128; break;
 	case PTP_DTC_UINT128:	dst->u128 = src->u128; break;
 #endif
-	case PTP_DTC_STR: 	dst->str = strdup(src->str); break;
 	default:		break;
 	}
 	return;
@@ -881,8 +973,8 @@ duplicate_DevicePropDesc(const PTPDevicePropDesc *src, PTPDevicePropDesc *dst) {
 	dst->DataType		= src->DataType;
 	dst->GetSet		= src->GetSet;
 	
-	duplicate_PropertyValue (&src->FactoryDefaultValue, &dst->FactoryDefaultValue, dst->DataType);
-	duplicate_PropertyValue (&src->CurrentValue, &dst->CurrentValue, dst->DataType);
+	duplicate_PropertyValue (&src->FactoryDefaultValue, &dst->FactoryDefaultValue, src->DataType);
+	duplicate_PropertyValue (&src->CurrentValue, &dst->CurrentValue, src->DataType);
 
 	dst->FormFlag		= src->FormFlag;
 	switch (src->FormFlag) {
@@ -1807,6 +1899,7 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 				case PTP_DPC_CANON_EOS_DepthOfField:
 				case PTP_DPC_CANON_EOS_LvViewTypeSelect:
 				case PTP_DPC_CANON_EOS_AloMode:
+				case PTP_DPC_CANON_EOS_Brightness:
 					dpd->DataType = PTP_DTC_UINT32;
 					ptp_debug (params, "event %d: Unknown EOS property %04x, datasize is %d, using uint32", i ,proptype, size-PTP_ece_Prop_Val_Data);
 					if ((size-PTP_ece_Prop_Val_Data) % sizeof(uint32_t) != 0)
@@ -1892,9 +1985,9 @@ ptp_unpack_CANON_changes (PTPParams *params, unsigned char* data, int datasize,
 				break;
 		}
 		case PTP_EC_CANON_EOS_CameraStatusChanged:
-			ptp_debug (params, "event %d: EOS event CameraStatusChanged (size %d)", i, size);
 			(*ce)[i].type = PTP_CANON_EOS_CHANGES_TYPE_CAMERASTATUS;
 			(*ce)[i].u.status =  dtoh32a(curdata+8);
+			ptp_debug (params, "event %d: EOS event CameraStatusChanged (size %d) = %d", i, size, dtoh32a(curdata+8));
 			params->eos_camerastatus = dtoh32a(curdata+8);
 			break;
 		case 0: /* end marker */
