@@ -14,10 +14,12 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
+#define _BSD_SOURCE
+
 #include "config.h"
 
 #include <stdio.h>
@@ -624,30 +626,27 @@ int
 sony_file_count(Camera * camera, SonyFileType file_type, int *count)
 {
 	Packet dp;
-	int rc;
+	int rc, nr;
 
 	GP_DEBUG( "sony_file_count()");
-	if (file_type == SONY_FILE_MPEG
-	    && (! sony_is_mpeg_supported(camera))) {
-		    rc = GP_OK;
-		    *count = 0;
+	if (file_type == SONY_FILE_MPEG && (! sony_is_mpeg_supported(camera))) {
+		*count = 0;
+		return GP_OK;
 	}
-	else {
-		*count = -1;
-		rc = sony_converse(camera, &dp, SetTransferRate, 4);
-		if (rc == GP_OK) {
-			int rc = sony_set_file_mode(camera, file_type);
-			if (rc == GP_OK) {
-				rc = sony_converse(camera, &dp, SendImageCount, 3);
-				if (rc == GP_OK) {
-					int nr = dp.buffer[5] | (dp.buffer[4]<<8);
-					GP_DEBUG ("count = %d", nr);
-					*count = nr;
-				}
-			}
-		}
-	}
-	return rc;
+	*count = -1;
+	rc = sony_converse(camera, &dp, SetTransferRate, 4);
+	if (rc != GP_OK)
+		return rc;
+	rc = sony_set_file_mode(camera, file_type);
+	if (rc != GP_OK)
+		return rc;
+	rc = sony_converse(camera, &dp, SendImageCount, 3);
+	if (rc != GP_OK)
+		return rc;
+	nr = dp.buffer[5] | (dp.buffer[4]<<8);
+	GP_DEBUG ("count = %d", nr);
+	*count = nr;
+	return GP_OK;
 }
 
 
@@ -658,25 +657,25 @@ sony_file_count(Camera * camera, SonyFileType file_type, int *count)
 int
 sony_file_name_get(Camera *camera, int imageid, SonyFileType mpeg, char buf[13])
 {
-       Packet dp;
-       int rc;
+	Packet dp;
+	int rc;
 
-       GP_DEBUG( "sony_file_name_get()");
-       rc = sony_set_file_mode(camera, mpeg);
-       if (rc == GP_OK) {
-	       sony_baud_set(camera, baud_rate);
-	       /* FIXME: Not nice, changing global data like this. */
-	       SelectImage[3] = (imageid >> 8);
-	       SelectImage[4] = imageid & 0xff;
-	       rc = sony_converse(camera, &dp, SelectImage, 7);
-	       if (rc == GP_OK) {
-		       memcpy(buf, &dp.buffer[5], 8);
-		       buf[8] = '.';
-		       memcpy(buf+9, &dp.buffer[5+8], 3);
-		       buf[12] = 0;
-	       }
-       }
-       return rc;
+	GP_DEBUG( "sony_file_name_get()");
+	rc = sony_set_file_mode(camera, mpeg);
+	if (rc != GP_OK)
+		return rc;
+	sony_baud_set(camera, baud_rate);
+	/* FIXME: Not nice, changing global data like this. */
+	SelectImage[3] = (imageid >> 8);
+	SelectImage[4] = imageid & 0xff;
+	rc = sony_converse(camera, &dp, SelectImage, 7);
+	if (rc != GP_OK)
+		return rc;
+	memcpy(buf, &dp.buffer[5], 8);
+	buf[8] = '.';
+	memcpy(buf+9, &dp.buffer[5+8], 3);
+	buf[12] = 0;
+	return rc;
 }
 
 
@@ -722,7 +721,6 @@ sony_file_get(Camera * camera, int imageid, int file_type,
 		 * overwrites it with the correct one.
 		 */
 		sprintf(buffer, SONY_FILE_NAME_FMT, imageid);
-		gp_file_set_name (file, buffer);
 
 		sony_baud_set(camera, baud_rate);
 
