@@ -17,8 +17,8 @@
  * \par
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 #include "config.h"
 #include <gphoto2/gphoto2-widget.h>
@@ -397,9 +397,9 @@ gp_widget_set_value (CameraWidget *widget, const void *value)
 	case GP_WIDGET_MENU:
 	case GP_WIDGET_RADIO:
         case GP_WIDGET_TEXT:
-		gp_log (GP_LOG_DEBUG, "gphoto2-widget", "Setting value to "
-			"'%s'...", (char*) value);
-	        if (widget->value_string) {
+		gp_log (GP_LOG_DEBUG, "gphoto2-widget", "Setting value of widget "
+			"'%s' to '%s'...", widget->label, (char*) value);
+			if (widget->value_string) {
                 	if (strcmp (widget->value_string, (char*) value))
                     		widget->changed = 1;
                 	free (widget->value_string);
