@@ -29,6 +29,8 @@
  ************************************************************************/
 
 # include <windows.h>
+/* done by mingw/wine headers ... defined to struct ... tsaes*/
+#undef interface
 # include <sys/types.h>
 # include <sys/stat.h>
 # include <string.h>
@@ -54,7 +56,7 @@ typedef struct {
 } GPPORTWINDIR;
 
 /* Sleep functionality */
-# define GP_SYSTEM_SLEEP(_ms)	  do { Sleep(_ms) } while (0)
+# define GP_SYSTEM_SLEEP(_ms)	  do { Sleep(_ms); } while (0)
 
 /* Directory-oriented functions */
 # define gp_system_dir		  GPPORTWINDIR *
