@@ -29,12 +29,14 @@
 #include <stdio.h>
 #include <gphoto2/gphoto2-port.h>
 #include <gphoto2/gphoto2-port-result.h>
+#include <gphoto2/gphoto2-port-portability.h>
 
 /* Windows Portability
    ------------------------------------------------------------------ */
 #ifdef WIN32
 
-void gp_port_win_convert_path (const char *path) {
+
+void gp_port_win_convert_path (char *path) {
 
         int x;
 
@@ -60,7 +62,15 @@ int gp_system_mkdir (const char *dirname) {
         return (GP_OK);
 }
 
-GP_SYSTEM_DIR gp_system_opendir (const char *dirname) {
+int gp_system_rmdir (const char *dirname) {
+
+        if (_rmdir(dirname) < 0)
+                return (GP_ERROR);
+        return (GP_OK);
+}
+
+
+gp_system_dir gp_system_opendir (const char *dirname) {
 
         GPPORTWINDIR *d;
         DWORD dr;
@@ -85,7 +95,7 @@ GP_SYSTEM_DIR gp_system_opendir (const char *dirname) {
         return (d);
 }
 
-GP_SYSTEM_DIRENT gp_system_readdir (GP_SYSTEM_DIR d) {
+gp_system_dirent gp_system_readdir (gp_system_dir d) {
 
         char dirn[1024];
 
@@ -120,12 +130,12 @@ GP_SYSTEM_DIRENT gp_system_readdir (GP_SYSTEM_DIR d) {
         return (&(d->search));
 }
 
-const char *gp_system_filename (GP_SYSTEM_DIRENT de) {
+const char *gp_system_filename (gp_system_dirent de) {
 
         return (de->cFileName);
 }
 
-int gp_system_closedir (GP_SYSTEM_DIR d) {
+int gp_system_closedir (gp_system_dir d) {
         FindClose(d->handle);
         free(d);
         return (1);
