@@ -1,5 +1,6 @@
 var NAVTREEINDEX3 =
 {
+"gphoto2-port-info-list_8h.html#a4621674c74440cc4d68d24e45fc9f148":[2,0,3,0,0,18],
 "gphoto2-port-info-list_8h.html#a541be7394f5ab48304fe48e5a6cec757":[2,0,3,0,0,0],
 "gphoto2-port-info-list_8h.html#a61b08d6eddea3c0e0c51869363632cea":[2,0,3,0,0,11],
 "gphoto2-port-info-list_8h.html#a625daffc59c3fd87b9f3b73b129f3b96":[2,0,3,0,0,3],
@@ -248,6 +249,5 @@ var NAVTREEINDEX3 =
 "gphoto2-result_8h.html#a824a44c818defda66b58058cff4fe098":[2,0,1,7,4],
 "gphoto2-result_8h.html#aa2ccbde81e188dc5f718a5f219118ff3":[2,0,1,7,8],
 "gphoto2-result_8h.html#adcbc9d96b811ff4bbcaa56a15c3776bb":[2,0,1,7,1],
-"gphoto2-result_8h.html#ade2d19223246e133a72869939d103a98":[2,0,1,7,3],
-"gphoto2-result_8h.html#aeedb403d0eb07560182191c551dc5178":[2,0,1,7,12]
+"gphoto2-result_8h.html#ade2d19223246e133a72869939d103a98":[2,0,1,7,3]
 };
