@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"gphoto2-result_8h.html#aeedb403d0eb07560182191c551dc5178":[2,0,1,7,12],
 "gphoto2-result_8h_source.html":[2,0,1,7],
 "gphoto2-setting_8c.html":[2,0,2,17],
 "gphoto2-setting_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,2,17,3],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "struct__CameraFileInfoFile.html#a6f4e10ef142ae1126784ff1f826a78fe":[1,0,6,3],
 "struct__CameraFileInfoFile.html#a78631442027c5f7134498ba323891ed3":[1,0,6,4],
 "struct__CameraFileInfoFile.html#a8b798b3031a1998be77beb5ba547cb62":[1,0,6,6],
-"struct__CameraFileInfoFile.html#a8cc5d010274aec1dfc222f1649133e2f":[1,0,6,7],
-"struct__CameraFileInfoFile.html#ae7acce7dab662a7dfb088602176ac20b":[1,0,6,2]
+"struct__CameraFileInfoFile.html#a8cc5d010274aec1dfc222f1649133e2f":[1,0,6,7]
 };
